SLiCAP Manual — SLiCAP 4.0.7 documentation

# SLiCAP Manual

Welcome to the version 4 manual of SLiCAP. This edition surpasses all previous versions and has been completely rewritten.

SLiCAP is a S ymbolic Li near C ircuit A nalysis P rogram, is designed to set up and solve equations for analog circuit design and automatically update design data in documentation.

SLiCAP is written in Python.

SLiCAP is distributed under the MIT license

## What you can find in this manual

Below, you find short descriptions of the main sections of this manual, listed in the side menu.

### SLiCAP Version 4

SLiCAP Version 4 includes:

1. An introduction to SLiCAP

2. Version 4 Release Notes

3. A short guidance how to use SLiCAP in conjunction with Structured Electronic Design

4. A list of contributers to SLiCAP.

### SLiCAP User Guide

The User Guide provides a comprehensive guide to using SLiCAP, covering everything from installation to executing fully documented design projects.

SLiCAP output displayed in this SLiCAP user guide, is generated with the script: manual.py.

    #!/usr/bin/env python3
    # -*- coding: utf-8 -*-

    """
    Manual.py: SLiCAP scripts for the HTML help file
    """

    from SLiCAP import initProject

    initProject("Manual")
    # Import scripts for HTML help
    from circuit import *
    from specifications import *
    from parameters import *
    from models import *
    from subcircuits import *
    from matrix import *
    from laplace import *
    from pz import *
    from ttime import *
    from noise import *
    from dcvar import *
    from feedback import *
    from balanced import *
    from math import *
    from ngspice import *
    from plots import *

Warning: running this script may take a while!

This is because:

1. `feedback.py` Compares symbolic circuit analysis results obtained with the asymptotic-gain feedback model with the results obtained from Modified Nodal Analysis. The sole purpose of this is to illustrate the correctness of the feedback model for those unacquainted with it. As stated in How to Use SLiCAP, working with such complex multi-variable expressions is not encouraged.

2. The script `plots.py` shows a plot of a periodic pulse response obtained from a single unit step response. Periodic pulses created in this way use the Heaviside function. The numeric evaluation of expressions with this function may take a while.

### SLiCAP Examples and Tutorials

SLiCAP Examples and Tutorials gives descriptive links to github SLiCAPexamples.

### SLiCAP Netlist syntax

The SLiCAP netlist syntax slightly deviates from standard SPICE. SLiCAP Netlist Syntax describes the netlist syntax, including all built-in devices and models.

### SLiCAP Reference

SLiCAP Reference documents all SLiCAP user callable functions and objects.